@@ -18,6 +18,7 @@ import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredE
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableRequestType;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableWhy;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.OperationResult;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 
 import com.allen_sauer.gwt.log.client.Log;
@@ -46,18 +47,17 @@ import com.sencha.gxt.widget.core.client.form.FieldLabel;
  */
 public class ChangeTableTypePanel extends FramedPanel implements
 		MonitorDialogListener {
-	protected String WIDTH = "640px";
-	protected String HEIGHT = "520px";
+	private static final String WIDTH = "640px";
+	private static final String HEIGHT = "520px";
 
-	protected TRId trId;
-	protected TableData table;
-	protected String headingTitle;
-	protected VerticalLayoutContainer vl;
-	protected EventBus eventBus;
-	protected ChangeTableTypeSession changeTableTypeSession;
+	private TRId trId;
+	private TableData table;
+	private VerticalLayoutContainer vl;
+	private EventBus eventBus;
+	private ChangeTableTypeSession changeTableTypeSession;
 
-	protected ComboBox<TableTypeElement> comboTableType;
-	protected TextButton change;
+	private ComboBox<TableTypeElement> comboTableType;
+	private TextButton change;
 
 	public ChangeTableTypePanel(TRId trId, EventBus eventBus) {
 		super();
@@ -92,10 +92,10 @@ public class ChangeTableTypePanel extends FramedPanel implements
 		comboTableType.setEditable(false);
 		comboTableType.setTriggerAction(TriggerAction.ALL);
 
-		change = new TextButton("Change");
+		change = new TextButton("Apply");
 		change.setIcon(ResourceBundle.INSTANCE.tableType());
 		change.setIconAlign(IconAlign.RIGHT);
-		change.setTitle("Change Table Type");
+		change.setTitle("Apply Table Type");
 
 		change.addSelectHandler(new SelectHandler() {
 
@@ -158,7 +158,7 @@ public class ChangeTableTypePanel extends FramedPanel implements
 											+ caught.getLocalizedMessage());
 									UtilsGXT3
 											.alert("Error Changing The Table Type",
-													"Error in invocation of Change Table Type operation!");
+													"Error in invocation of Change Table Type operation! "+caught.getLocalizedMessage());
 								}
 							}
 						}
@@ -195,9 +195,9 @@ public class ChangeTableTypePanel extends FramedPanel implements
 										caught.getLocalizedMessage());
 							} else {
 								Log.error("Error retrieving table: "
-										+ caught.getMessage());
+										+ caught.getLocalizedMessage());
 								UtilsGXT3.alert("Error retrieving table",
-										caught.getMessage());
+										caught.getLocalizedMessage());
 							}
 						}
 					}
@@ -232,10 +232,10 @@ public class ChangeTableTypePanel extends FramedPanel implements
 	}
 
 	@Override
-	public void operationComplete(TRId trId) {
+	public void operationComplete(OperationResult operationResult) {
 		ChangeTableWhy why = ChangeTableWhy.TABLEUPDATED;
 		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
-				ChangeTableRequestType.CHANGETABLETYPE, trId, why);
+				ChangeTableRequestType.CHANGETABLETYPE, operationResult.getTrId(), why);
 		eventBus.fireEvent(changeTableRequestEvent);
 		close();
 	}
@@ -248,10 +248,10 @@ public class ChangeTableTypePanel extends FramedPanel implements
 	}
 
 	@Override
-	public void operationStopped(TRId trId, String reason, String details) {
+	public void operationStopped(OperationResult operationResult, String reason, String details) {
 		ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
 		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
-				ChangeTableRequestType.CHANGETABLETYPE, trId, why);
+				ChangeTableRequestType.CHANGETABLETYPE, operationResult.getTrId(), why);
 		eventBus.fireEvent(changeTableRequestEvent);
 		close();
 
