@@ -2,6 +2,7 @@ package org.gcube.portlets.user.td.tablewidget.client.geospatial;
 
 import java.util.ArrayList;
 
+import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnDataPropertiesCombo;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
@@ -10,7 +11,6 @@ import org.gcube.portlets.user.td.gwtservice.shared.geospatial.GeospatialCreateC
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialog;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
 import org.gcube.portlets.user.td.columnwidget.client.geospatial.GeospatialCoordinatesTypePropertiesCombo;
-import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnDataPropertiesCombo;
 import org.gcube.portlets.user.td.tablewidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.tablewidget.client.util.UtilsGXT3;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.ChangeTableRequestEvent;
